MAGICAL Explorer

# MAGICAL Circuit Dashboard

Inferred regulatory circuit dashboard.

Select Result Set
0
Inferred Circuits
0
Target Genes
0
Active TFs

## Top 10 Most Present Genes

## TF Landscape

## Score Distribution

Group by Gene/Peak

Gene | TF | Overall Effect | Circuit Prob | Looping (L) | Binding (B) | Peak Location
--- | --- | --- | --- | --- | --- | ---

Please run `python update_ui.py` to load your data.

×

## ---

Click a gene to see information...
View on GeneCards ↗